@@ -6,6 +6,6 @@ from encrypti0n.classes import *
 
 # source path & version.
 import fil3s
-source_path = fil3s.gfp.base(__file__)
-try: version = fil3s.Files.load(source_path+".version.py").replace("\n","").replace(" ","")
+source = fil3s.gfp.base(__file__)
+try: version = fil3s.Files.load(source+".version.py").replace("\n","").replace(" ","")
 except: version = None
\ No newline at end of file
