@@ -28,7 +28,7 @@ class AES(object):
 	def __init__(self, passphrase=None):
 		
 		# check params.
-		response = r3sponse.check_parameters({
+		response = r3sponse.parameters.check({
 			"passphrase:str":passphrase,})
 		if not response.success: raise ValueError(response.error)
 
@@ -187,7 +187,7 @@ class AsymmetricAES(object):
 		output = Formats.denitialize(output)
 
 		# check params.
-		response = r3sponse.check_parameters({
+		response = r3sponse.parameters.check({
 			"input":input,
 			"output":output,})
 		if not response.success: return response
@@ -217,7 +217,7 @@ class AsymmetricAES(object):
 		output = Formats.denitialize(output)
 
 		# check params.
-		response = r3sponse.check_parameters({
+		response = r3sponse.parameters.check({
 			"input":input,
 			"output":output,})
 		if not response.success: return response
@@ -366,8 +366,11 @@ class Database(object):
 		path=None,
 	):
 
+		# defaults.
+		#self.__class__.__name__ = "Database"
+
 		# check params.
-		response = r3sponse.check_parameters({
+		response = r3sponse.parameters.check({
 			"aes:object":aes,
 			"path:str":path,})
 		if not response.success: raise ValueError(response.error)
@@ -414,7 +417,7 @@ class Database(object):
 		save=True,
 	):
 		if not self.activated: return r3sponse.error(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
-		response = r3sponse.check_parameters({
+		response = r3sponse.parameters.check({
 			"path:str":path,
 			"default:str,dict,list,int,float":default,
 			"save:bool":save,})
@@ -435,7 +438,7 @@ class Database(object):
 		default=None,
 	):
 		if not self.activated: return r3sponse.error(f"Encrypted database [{self.path}] is not activated yet, call database.activate() first.")
-		response = r3sponse.check_parameters({
+		response = r3sponse.parameters.check({
 			"path:str":path,})
 		if not response.success: return response
 		path = gfp.clean(f"{self.path}/{path}", remove_last_slash=True, remove_double_slash=True)
@@ -485,7 +488,7 @@ class Database(object):
 		content=None,
 	):
 		if not self.activated: return r3sponse.error(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
-		response = r3sponse.check_parameters({
+		response = r3sponse.parameters.check({
 			"content:object":content,})
 		if not response.success: return response
 		response = content.save()
@@ -514,6 +517,9 @@ class Database(object):
 			# the aes object.
 			aes=None,
 		):
+			# defaults.
+			#self.__class__.__name__ = "File"
+			# attributesl
 			self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}"
 			self.base = FilePath(self.path).base()
 			self.aes = aes
@@ -552,6 +558,9 @@ class Database(object):
 			# the aes object.
 			aes=None,
 		):
+			# defaults.
+			#self.__class__.__name__ = "Array"
+			# attributes.
 			self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}"
 			self.base = FilePath(self.path).base()
 			self.aes = aes
@@ -595,6 +604,9 @@ class Database(object):
 			# the aes object.
 			aes=None,
 		):
+			# defaults.
+			#self.__class__.__name__ = "Dictionary"
+			# attributesl
 			self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}"
 			self.base = FilePath(self.path).base()
 			self.aes = aes
