@@ -30,6 +30,8 @@ class RSA(object):
 		# defaults.
 		self.passphrase = passphrase
 		self.memory = memory
+		self.private_key_object = None
+		self.public_key_object = None
 		
 		# options.
 		if self.memory:
@@ -112,24 +114,19 @@ class RSA(object):
 
 
 		# initialize keys.
-		if self.passphrase == None:
-			try:
+		try:
+			if self.passphrase == None:
 				self.public_key_object = _RSA_.importKey(str(self.public_key_data))
 				self.private_key_object = _RSA_.importKey(str(self.private_key_data))
-			except ValueError as e:
-				if "Padding is incorrect" in str(e):
-					response["error"] = "Provided an incorrect passphrase."
-				else: response["error"] = f"ValueError: {e}"
-				return response
-		else:
-			try:
+			else:
 				self.public_key_object = _RSA_.importKey(str(self.public_key_data))
 				self.private_key_object = _RSA_.importKey(str(self.private_key_data), passphrase=self.passphrase)
-			except ValueError as e:
-				if "Padding is incorrect" in str(e):
-					response["error"] = "Provided an incorrect passphrase."
-				else: response["error"] = f"ValueError: {e}"
-				return response
+		except ValueError as e:
+			self.public_key_object = None
+			self.private_key_object = None
+			if "Padding is incorrect" in str(e):
+				return r3sponse.error("Provided an incorrect passphrase.")
+			else: return r3sponse.error(f"ValueError: {e}")
 		
 		# response.
 		return r3sponse.success("Successfully loaded the key pair.")
@@ -146,8 +143,9 @@ class RSA(object):
 
 		# initialize keys.
 		try:
-			self.public_key_object = _RSA_.importKey(self.public_key_data)
+			self.public_key_object = _RSA_.importKey(str(self.public_key_data))
 		except ValueError as e:
+			self.public_key_object = None
 			if "Padding is incorrect" in str(e):
 				response["error"] = "Provided an incorrect passphrase."
 			else: response["error"] = f"ValueError: {e}"
@@ -169,16 +167,18 @@ class RSA(object):
 		# initialize keys.
 		if self.passphrase == None:
 			try:
-				self.private_key_object = _RSA_.importKey(self.private_key_data)
+				self.private_key_object = _RSA_.importKey(str(self.private_key_data))
 			except ValueError as e:
+				self.private_key_object = None
 				if "Padding is incorrect" in str(e):
 					response["error"] = "Provided an incorrect passphrase."
 				else: response["error"] = f"ValueError: {e}"
 				return response
 		else:
 			try:
-				self.private_key_object = _RSA_.importKey(self.private_key_data, passphrase=self.passphrase)
+				self.private_key_object = _RSA_.importKey(str(self.private_key_data), passphrase=self.passphrase)
 			except ValueError as e:
+				self.private_key_object = None
 				if "Padding is incorrect" in str(e):
 					response["error"] = "Provided an incorrect passphrase."
 				else: response["error"] = f"ValueError: {e}"
@@ -203,7 +203,7 @@ class RSA(object):
 		# response.
 		response = utils.__default_response__()
 		if "Your identification has been saved with the new passphrase." in output:
-			self.private_key_data = Files.load(private_key)
+			self.private_key_data = str(Files.load(private_key))
 			if not self.memory:
 				os.system(f"rm -fr {private_key}")
 			self.passphrase = passphrase
@@ -217,8 +217,35 @@ class RSA(object):
 
 		#
 	# encrypting.
+	def encrypt_string(self, string, layers=1, decode=True):
+
+		# checks.
+		if not self.public_key_activated:
+			return r3sponse.error("Can not encrypt data since the public key is not activated yet.")
+
+		# encrypt.
+		response = utils.__default_response__()
+		encrypted = self.__encrypt_blob__(string, self.public_key_object)
+
+		# layers.
+		if layers-1 > 0:
+			return self.encrypt_string(encrypted, layers=layers-1)
+		else:
+			response["success"] = True
+			response["message"] = f"Successfully encrypted the string."
+			if decode:
+				response["encrypted"] = encrypted.decode()
+			else:
+				response["encrypted"] = encrypted
+			return response
+
+		#
 	def encrypt_file(self, path, layers=1):
 
+		# checks.
+		if not self.public_key_activated:
+			return r3sponse.error("Can not encrypt data since the public key is not activated yet.")
+
 		# encrypt.
 		response = utils.__default_response__()
 		bytes = utils.__load_bytes__(path)
@@ -235,6 +262,10 @@ class RSA(object):
 	def encrypt_directory(self, path, recursive=False, layers=1):
 		response = utils.__default_response__()
 
+		# checks.
+		if not self.public_key_activated:
+			return r3sponse.error("Can not encrypt data since the public key is not activated yet.")
+
 		# recursively encrypt all files.
 		if recursive:
 
@@ -288,46 +319,14 @@ class RSA(object):
 				zip.file_path.delete(forced=True)
 				return response
 
-		#
-	def encrypt_string(self, string, layers=1, decode=True):
-
-		# encrypt.
-		response = utils.__default_response__()
-		encrypted = self.__encrypt_blob__(string, self.public_key_object)
-
-		# layers.
-		if layers-1 > 0:
-			return self.encrypt_string(encrypted, layers=layers-1)
-		else:
-			response["success"] = True
-			response["message"] = f"Successfully encrypted the string."
-			if decode:
-				response["encrypted"] = encrypted.decode()
-			else:
-				response["encrypted"] = encrypted
-			return response
-
 		#
 	# decrypting.
-	def decrypt_file(self, path, layers=1):
-
-		# encrypt.
-		response = utils.__default_response__()
-		bytes = utils.__load_bytes__(path)
-		decrypted = self.__decrypt_blob__(bytes, self.private_key_object)
-		utils.__save_bytes__(path, decrypted)
-		
-		# layers.
-		if layers-1 > 0:
-			return self.decrypt_file(path, layers=layers-1)
-		else:
-			response["success"] = True
-			response["message"] = f"Successfully decrypted file [{path}]."
-			return response
-
-		#
 	def decrypt_string(self, string, layers=1, decode=True):
 		
+		# checks.
+		if not self.private_key_activated:
+			return r3sponse.error("Can not decrypt data since the private key is not activated yet.")
+
 		# decrypt.
 		response = utils.__default_response__()
 		if isinstance(string,str): string = string.encode()
@@ -345,8 +344,35 @@ class RSA(object):
 				response["decrypted"] = decrypted
 			return response
 
+		#
+	def decrypt_file(self, path, layers=1):
+
+		# checks.
+		if not self.private_key_activated:
+			return r3sponse.error("Can not decrypt data since the private key is not activated yet.")
+
+		# encrypt.
+		response = utils.__default_response__()
+		bytes = utils.__load_bytes__(path)
+		decrypted = self.__decrypt_blob__(bytes, self.private_key_object)
+		utils.__save_bytes__(path, decrypted)
+		
+		# layers.
+		if layers-1 > 0:
+			return self.decrypt_file(path, layers=layers-1)
+		else:
+			response["success"] = True
+			response["message"] = f"Successfully decrypted file [{path}]."
+			return response
+
 		#
 	def decrypt_directory(self, path, recursive=False, layers=1):
+
+		# checks.
+		if not self.private_key_activated:
+			return r3sponse.error("Can not decrypt data since the private key is not activated yet.")
+
+		# defaults.
 		response = utils.__default_response__()
 
 		# recursively decrypt all files.
@@ -489,6 +515,18 @@ class RSA(object):
 
 		#return the decompressed decrypted data
 		return zlib.decompress(decrypted)
+	# properties.
+	@property
+	def activated(self):
+		return str(self.private_key_object) != str(None) and str(self.public_key_object) != str(None)
+	@property
+	def private_key_activated(self):
+		return str(self.private_key_object) != str(None)
+	@property
+	def public_key_activated(self):
+		return str(self.public_key_object) != str(None)
+
+	
 
 # the encrypted dictionary class.
 class EncryptedDictionary(Dictionary):
